@@ -3,8 +3,8 @@ from copy import copy
 from .fieldsets import action_fields
 
 
-class ModelAdminActionItemMixin:
-    def get_readonly_fields(self, request, obj=None):
+class ActionItemModelAdminMixin:
+    def get_readonly_fields(self, request, obj=None) -> tuple:
         """
         Returns a list of readonly field names.
 
@@ -14,4 +14,4 @@ class ModelAdminActionItemMixin:
         fields = super().get_readonly_fields(request, obj=obj)
         action_flds = copy(list(action_fields))
         action_flds.remove("action_identifier")
-        return list(fields) + list(action_flds)
+        return tuple(fields) + tuple(action_flds)
